==> webkitgtk-2.6.2.tar.xz: webkitgtk-2.6.2/Source/WebCore/inspector/InspectorAllInOne.cpp <==
/*
 * Copyright (C) 2012 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. ``AS IS'' AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL APPLE INC. OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY
 * OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

// This all-in-one cpp file cuts down on template bloat to allow us to build our Windows release build.

#include "CommandLineAPIHost.cpp"
#include "CommandLineAPIModule.cpp"
#include "DOMEditor.cpp"
#include "DOMPatchSupport.cpp"
#include "InspectorApplicationCacheAgent.cpp"
#include "InspectorCSSAgent.cpp"
#include "InspectorClient.cpp"
#include "InspectorController.cpp"
#include "InspectorDOMAgent.cpp"
#include "InspectorDOMDebuggerAgent.cpp"
#include "InspectorDOMStorageAgent.cpp"
#include "InspectorDatabaseAgent.cpp"
#include "InspectorDatabaseResource.cpp"
#include "InspectorFrontendClientLocal.cpp"
#include "InspectorFrontendHost.cpp"
#include "InspectorHistory.cpp"
#include "InspectorIndexedDBAgent.cpp"
#include "InspectorInstrumentation.cpp"
#include "InspectorInstrumentationCookie.cpp"
#include "InspectorLayerTreeAgent.cpp"
#include "InspectorNodeFinder.cpp"
#include "InspectorOverlay.cpp"
#include "InspectorPageAgent.cpp"
#include "InspectorResourceAgent.cpp"
#include "InspectorStyleSheet.cpp"
#include "InspectorStyleTextEditor.cpp"
#include "InspectorTimelineAgent.cpp"
#include "InspectorWorkerAgent.cpp"
#include "InstrumentingAgents.cpp"
#include "NetworkResourcesData.cpp"
#include "PageConsoleAgent.cpp"
#include "PageDebuggerAgent.cpp"
#include "PageRuntimeAgent.cpp"
#include "PageScriptDebugServer.cpp"
#include "TimelineRecordFactory.cpp"
#include "WebConsoleAgent.cpp"
#include "WebDebuggerAgent.cpp"
#include "WebInjectedScriptHost.cpp"
#include "WebInjectedScriptManager.cpp"
#include "WorkerConsoleAgent.cpp"
#include "WorkerDebuggerAgent.cpp"
#include "WorkerInspectorController.cpp"
#include "WorkerRuntimeAgent.cpp"

==> webkitgtk-2.14.2.tar.xz: webkitgtk-2.14.2/Source/WebCore/inspector/InspectorAllInOne.cpp <==
/*
 * Copyright (C) 2012 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. ``AS IS'' AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL APPLE INC. OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY
 * OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

// This all-in-one cpp file cuts down on template bloat to allow us to build our Windows release build.

#include "CommandLineAPIHost.cpp"
#include "CommandLineAPIModule.cpp"
#include "DOMEditor.cpp"
#include "DOMPatchSupport.cpp"
#include "InspectorApplicationCacheAgent.cpp"
#include "InspectorCSSAgent.cpp"
#include "InspectorClient.cpp"
#include "InspectorController.cpp"
#include "InspectorDOMAgent.cpp"
#include "InspectorDOMDebuggerAgent.cpp"
#include "InspectorDOMStorageAgent.cpp"
#include "InspectorDatabaseAgent.cpp"
#include "InspectorDatabaseResource.cpp"
#include "InspectorFrontendClientLocal.cpp"
#include "InspectorFrontendHost.cpp"
#include "InspectorHistory.cpp"
#include "InspectorInstrumentation.cpp"
#include "InspectorInstrumentationCookie.cpp"
#include "InspectorLayerTreeAgent.cpp"
#include "InspectorNetworkAgent.cpp"
#include "InspectorNodeFinder.cpp"
#include "InspectorOverlay.cpp"
#include "InspectorPageAgent.cpp"
#include "InspectorStyleSheet.cpp"
#include "InspectorTimelineAgent.cpp"
#include "InstrumentingAgents.cpp"
#include "NetworkResourcesData.cpp"
#include "PageConsoleAgent.cpp"
#include "PageDebuggerAgent.cpp"
#include "PageHeapAgent.cpp"
#include "PageRuntimeAgent.cpp"
#include "PageScriptDebugServer.cpp"
#include "TimelineRecordFactory.cpp"
#include "WebConsoleAgent.cpp"
#include "WebDebuggerAgent.cpp"
#include "WebInjectedScriptHost.cpp"
#include "WebInjectedScriptManager.cpp"
